@@ -119,7 +119,7 @@ void on_miListV_activate(){
 
 void on_hcontents_activate(){
   char *str = (char*)malloc(5000 * sizeof(char));
-  sprintf(str, "\n\1Ajuda\5\n\n"
+  snprintf(str, 4999, "\n\1Ajuda\5\n\n"
       "Ao iniciar, o GConjugue carrega um banco de dados contendo verbos "
       "conjugados. Esses verbos são usados como paradigmas para a conjugação "
       "dos demais verbos presentes no banco. Alguns dos verbos estão "
@@ -201,7 +201,7 @@ void on_sobre1_activate(){
       "gconjugue is based on \"conjugue\", "
       "which was developed by Ricardo Ueda Karpischek\n\n"
       "gconjugue is free software under GNU GPL license.\n\n"
-      "Homepage:\nhttp://sites.google.com/site/jalvesaq/gconjugue"), VERSION);
+      "Homepage:\nhttp://www.lepem.ufc.br/jaa/gconjugue"), VERSION);
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 }
