@@ -3,17 +3,14 @@
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 **
-** (c) 2005-2008 Jakson Aquino: jalvesaq@gmail.com
+** (c) 2005-2011 Jakson Aquino: jalvesaq@gmail.com
 **
 ***************************************************************/
 
 #ifndef GCONJUGUE_INTERFACE_H
 #define GCONJUGUE_INTERFACE_H
 
-#include <libintl.h>
-#include <locale.h>
-
-#define _(string) gettext(string)
+#include <glib/gi18n.h>
 
 extern GtkWidget *window1;
 extern GtkWidget *vbox1;
