@@ -75,18 +75,18 @@ void initialize(int argc, char *argv[])
   confFileName = g_strdup_printf("%s/%s", g_get_home_dir(), ".gconjugue");
   FILE *F = fopen(confFileName, "r");
   if(F){
-    char s[32];
-    char b[32];
+    char s[128];
+    char b[128];
     i = 0;
-    while(fgets(s, 31, F)){
+    while(fgets(s, 127, F)){
       if(s[0] == '#' || strlen(s) < 6)
 	continue;
       i = 0;
-      sprintf(b, "height = %%d\n");
+      snprintf(b, 127, "height = %%d\n");
       if(sscanf(s, b, &i) == 1 && i > 100 && i < 1000)
 	initHeight = i;
       i = 0;
-      sprintf(b, "width = %%d\n");
+      snprintf(b, 127, "width = %%d\n");
       if(sscanf(s, b, &i) == 1 && i > 100 && i < 1500)
 	initWidth = i;
     }
